import { RtcEngineConfig } from "./c";
import { i1 } from "../n/o/p";
import { CameraInfo, CaptureConfig, VideoCaptureCapability } from "../q/r";
import { VideoEncoderConfiguration } from "./f";
import { Constants } from "./j";
import { RtcConnection } from "./h";
import { j1 } from "../n/s";
import l1 from 'libagora_rtc_sdk.so';
import { GenericReturnType } from "../q/t";
import camera from '@ohos.multimedia.camera';
import { CameraCapturerConfiguration } from "./g";
import { m1 } from "../n/u";
export class RtcEngine {
    static create(config) {
        return RtcEngineImpl.createEngineImpl(config);
    }
    static createEngine(context, appID, handler) {
        let config = new RtcEngineConfig();
        config.mContext = context;
        config.mAppId = appID;
        config.mEventHandler = handler;
        return RtcEngineImpl.createEngineImpl(config);
    }
    static getSdkVersion() {
        return RtcEngineImpl.getRtcSdkVersion();
    }
    ;
    ;
    static destroy() {
        return RtcEngineImpl.destroyEngine();
    }
    ;
}
export class RtcEngineEx extends RtcEngine {
}
var n1;
(function (n3) {
    n3[n3["i"] = 0] = "CameraStart";
    n3[n3["j"] = 1] = "CameraStop";
})(n1 || (n1 = {}));
export class RtcEngineImpl extends RtcEngineEx {
    constructor() {
        super();
        this.mCamera = new i1();
        this.initialized = false;
        this.encoderConfiguration = new VideoEncoderConfiguration();
        this.mContext = null;
        this.eventHandler = null;
        this.cameraMap = new Map;
        this.cameraStateMap = new Map;
        this.handlerMap = new Map;
        this.captureConfiguration = new CameraCapturerConfiguration();
        this.nativeRef = BigInt(0);
    }
    static createEngineImpl(config) {
        if (RtcEngineImpl.engine != null) {
            RtcEngineImpl.engine.reinitialize(config);
            return RtcEngineImpl.engine;
        }
        RtcEngineImpl.engine = new RtcEngineImpl();
        RtcEngineImpl.engine.initialize(config);
        return RtcEngineImpl.engine;
    }
    static getRtcSdkVersion() {
        return l1.getSdkVersion();
    }
    setLogFile(filePath) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setLogFile(filePath);
        return 0;
    }
    setLogFilter(filter) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.setLogFilter(filter);
    }
    setParameters(parameters) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setParameters(parameters);
        return 0;
    }
    startPreview() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.startPreview();
        return 0;
    }
    stopPreview() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.stopPreview();
        return 0;
    }
    enableEncryption(enabled, config) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.enableEncryption(enabled, config.encryptionMode, config.encryptionKey, config.encryptionKdfSalt);
        return 0;
    }
    joinChannel(key, l3, m3, uid) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.joinChannel(key, l3, uid);
        return 0;
    }
    joinChannelWithOptions(token, channelId, uid, options) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.joinChannelWithOptions(token, channelId, uid, options);
    }
    updateChannelMediaOptions(options) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.updateChannelMediaOptions(options);
    }
    leaveChannel() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.leaveChannel();
        return 0;
    }
    setupRemoteVideo(canvas) {
        l1.setupRemoteVideo(canvas.xcomponentId, canvas.uid, canvas.renderMode, canvas.mirrorMode);
        return 0;
    }
    setupLocalVideo(canvas) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setupLocalVideo(canvas.xcomponentId, 0, canvas.renderMode, canvas.mirrorMode);
        return 0;
    }
    enableLocalVideo(enabled) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.enableLocalVideo(enabled);
        return 0;
    }
    muteLocalVideoStream(muted) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.muteLocalVideoStream(muted);
        return 0;
    }
    muteLocalAudioStream(muted) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.muteLocalAudioStream(muted);
        return 0;
    }
    static destroyEngine() {
        if (RtcEngineImpl.engine == null)
            return new Promise((k3) => {
                k3();
            });
        RtcEngineImpl.engine.initialized = false;
        RtcEngineImpl.destroying = true;
        return l1.destroy().then(() => {
            RtcEngineImpl.destroying = false;
            RtcEngineImpl.engine = null;
        });
    }
    setVideoEncoderConfiguration(configuration) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        this.encoderConfiguration = configuration;
        l1.setVideoEncoderConfiguration(configuration);
        return 0;
    }
    setAudioProfile(profile) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.setAudioProfile(profile);
    }
    setAudioScenario(scenario) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.setAudioScenario(scenario);
    }
    startAudioRecording(filePath, quality) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.startAudioRecording(filePath, quality);
    }
    ;
    stopAudioRecording() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.stopAudioRecording();
    }
    ;
    setCameraProfile(h3) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        if (this.mContext != null) {
            this.mCamera.init(this.mContext);
            this.mCamera.m(h3);
        }
        return 0;
    }
    pushVideoFrame(buffer, width, height, rotation) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.pushVideoFrame(buffer, width, height, rotation);
        return 0;
    }
    setChannelProfile(profile) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setChannelProfile(profile);
        return 0;
    }
    switchCamera() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.switchCamera();
        return 0;
    }
    getCameraInfo(context) {
        let d3 = camera.getCameraManager(context);
        let e3 = d3.getSupportedCameras();
        let count = e3.length;
        let f3 = new Array();
        for (let g3 = 0; g3 < count; g3++) {
            let info = new CameraInfo();
            info.index = g3;
            info.cameraPosition = e3[g3].cameraPosition;
            info.cameraType = e3[g3].cameraType;
            info.connectionType = e3[g3].connectionType;
            f3.push(info);
        }
        return f3;
    }
    getDeviceSupportedFormats(context, index) {
        let w2 = camera.getCameraManager(context);
        let z2 = w2.getSupportedCameras();
        let capabilities = new Array();
        if (index >= z2.length || index < 0) {
            return capabilities;
        }
        let item = z2[index];
        let a3 = w2.getSupportedOutputCapability(item);
        let b3 = a3.videoProfiles;
        for (let profile of b3) {
            let c3 = new VideoCaptureCapability();
            c3.width = profile.size.width;
            c3.height = profile.size.height;
            c3.maxFramerate = profile.frameRateRange.max;
            c3.pixelFormat = profile.format;
            capabilities.push(c3);
        }
        return capabilities;
    }
    enableVideo() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        let f2 = this.getCameraInfo(this.mContext);
        l1.setCameraInfoList(f2);
        for (let u2 = 0; u2 < f2.length; u2++) {
            let v2 = this.getDeviceSupportedFormats(this.mContext, f2[u2].index);
            l1.setCameraSupportFormat(f2[u2].index, v2);
        }
        let g2 = [
            (obj) => {
                return this.getCameraInfo(this.mContext);
            },
            (obj) => {
                let t2 = obj['int'];
                return this.getDeviceSupportedFormats(this.mContext, t2);
            },
            (obj) => {
                let q2 = obj['index'];
                let r2 = obj['ref'];
                let s2 = new i1();
                s2.init(this.mContext);
                s2.m(q2);
                s2.o(r2);
                let callback = l1.getCameraCaptureNapiObject();
                s2.t(callback);
                this.cameraMap.set(r2, s2);
                return GenericReturnType.withInt(0);
            },
            (obj) => {
                let config = new CaptureConfig();
                let id = obj['ref_id'];
                config.width = obj['width'];
                config.height = obj['height'];
                config.framerate = obj['framerate'];
                let result = 0;
                this.cameraStateMap.set(id, n1.i);
                if (this.cameraMap.has(id)) {
                    let n2 = this.cameraMap.get(id);
                    n2.u(config).then(() => {
                        if (this.cameraStateMap.get(id) != n1.i) {
                            n2.a1();
                        }
                    });
                }
                return GenericReturnType.withInt(0);
            },
            (obj) => {
                let id = obj['ulong'];
                this.cameraStateMap.set(id, n1.j);
                if (this.cameraMap.has(id)) {
                    let m2 = this.cameraMap.get(id);
                    m2.a1();
                }
                return GenericReturnType.withInt(0);
            },
        ];
        l1.registerCameraFunctions(g2);
        return l1.enableVideo();
    }
    startAudioMixing(c2, d2, e2) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.startAudioMixing(c2, d2, e2);
    }
    pauseAudioMixing() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.pauseAudioMixing();
    }
    resumeAudioMixing() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.resumeAudioMixing();
    }
    stopAudioMixing() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.stopAudioMixing();
    }
    setAudioMixingPlaybackSpeed(speed) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.setAudioMixingPlaybackSpeed(speed);
    }
    getAudioMixingCurrentPosition() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        let b2 = l1.getAudioMixingCurrentPosition();
        return b2;
    }
    setClientRole(a2) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setClientRole(a2);
        return 0;
    }
    setExternalVideoSource(enable, z1, sourceType) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        l1.setExternalVideoSource(enable, z1, sourceType);
        return 0;
    }
    pushExternalVideoFrame(frame) {
        if (!this.initialized)
            return false;
        return l1.pushExternalVideoFrame(frame);
    }
    createCustomVideoTrack() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.createCustomVideoTrack();
    }
    destroyCustomVideoTrack(w1) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.destroyCustomVideoTrack(w1);
    }
    getCurrentMonotonicTimeInMs() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.getCurrentMonotonicTimeInMs();
    }
    joinChannelEx(token, connection, options, eventHandler) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        let handler = new j1(eventHandler, connection);
        this.handlerMap.set(connection, handler);
        return l1.joinChannelEx(token, connection, options, (eventId, event) => {
            handler.onEvent(eventId, event);
        });
    }
    pushExternalVideoFrameEx(frame, u1) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.pushExternalVideoFrameEx(frame, u1);
    }
    leaveChannelEx(connection) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.leaveChannelEx(connection);
    }
    startScreenCapture() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.startScreenCapture();
    }
    stopScreenCapture() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.stopScreenCapture();
    }
    createMediaRecorder(info) {
        let t1 = new m1(info);
        return t1;
    }
    destroyMediaRecorder(s1) {
        s1.release();
    }
    startLocalVideoTranscoder(config) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.startLocalVideoTranscoder(config);
    }
    stopLocalVideoTranscoder() {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.stopLocalVideoTranscoder();
    }
    updateLocalTranscoderConfiguration(config) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.updateLocalTranscoderConfiguration(config);
    }
    startCameraCapture(sourceType, config) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.startCameraCapture(sourceType, config);
    }
    stopCameraCapture(sourceType) {
        if (!this.initialized)
            return -Constants.ErrorCode.ERR_NOT_INITIALIZED;
        return l1.stopCameraCapture(sourceType);
    }
    reinitialize(config) {
        this.eventHandler = new j1(config.mEventHandler, new RtcConnection("", 0));
        return true;
    }
    initialize(config) {
        if (config.mContext == null || config.mAppId == null) {
            return false;
        }
        this.mContext = config.mContext;
        this.eventHandler = new j1(config.mEventHandler, new RtcConnection("", 0));
        let p1 = l1.initialize(config.mAppId, config.mContext.filesDir + "/", (eventId, event) => {
            this.eventHandler.onEvent(eventId, event);
        });
        if (p1 == 0) {
            this.initialized = true;
        }
        return true;
    }
}
RtcEngineImpl.destroying = false;
